@@ -981,7 +981,7 @@ class DevToplevel(tk.Toplevel, DevWindow):
 class DevTooltip(DevToplevel):
     def __init__(self, widget: tk.Widget, window: tk.Tk, message: str = "", after: int = 1000, border: bool = True, padding: int = 3, side=tk.CENTER, height: int = 40,
                  background="#ffffff", foreground="#000000"):
-        super(DevPreTooltip, self).__init__()
+        super(DevTooltip, self).__init__()
         self.configure(background=background, relief=tk.RAISED, border=1)
         from tkdev import window_border
         self._message = ttk.Label(self, background=background, foreground=foreground, text=message, anchor=tk.CENTER)
